@@ -54,11 +54,23 @@ var credits =
     ],
     [
         qsTr("Hatch Patterns"),
-        [ "John Hyslop",         "CELTIC-01, CELTIC-02, CIRCLES-02, CIRCLES, " +
-                                 "EXPLOSION, HEXAGONS, HOLLY, LATTICE-01, " +
-                                 "LATTICE-02, LATTICE-03, LATTICE-04, " +
-                                 "MAZE-01, MAZE-02, QCAD-LOGO, " +
-                                 "SQUIGGLE-01, SQUIGGLE-02" ],
+        [ "John Hyslop",         "BLOCKS-01, BLOCKS-01, " +
+                                 "BOXJOIN-01, BOXJOIN-02, " +
+                                 "BOX-OVERLAP, " +
+                                 "CELTIC-01, CELTIC-02, " +
+                                 "CIRCLES, CIRCLES-02, " +
+                                 "EXPLOSION, " +
+                                 "HEXAGONS, " +
+                                 "HEXJOIN-01, HEXJOIN-02, " +
+                                 "HOLLY, " +
+                                 "LATTICE-01, LATTICE-02, LATTICE-03, " +
+                                 "LATTICE-04, LATTICE-05, LATTICE-06, " +
+                                 "MAZE-01, MAZE-02, " +
+                                 "QCAD-LOGO, " +
+                                 "SCAFFOLD, " +
+                                 "SQUIGGLE-01, SQUIGGLE-02, " +
+                                 "TRI-OVERLAP"
+                                 ],
     ],
     [
         qsTr("Translations"),
